/**********************************************************************
 * Project: AderPlotter
 * Author: Andrew Deren <andrew@adersoftware.com>
 * http://www.adersoftware.com
 * Date: Feb. 2004
 * 
 * This program can be used for educational purposes only. 
 * For any other uses, please contact the author.
 **********************************************************************/

using System;
using System.Drawing;

using AderEvaluator.AST;
using AderEvaluator.Eval;
using AderEvaluator.Parser;

namespace AderPlotter.Controls
{

	public class EvalPlotter : IPlotter
	{
		Color color;

		string data;
		Expression exp;

		Evaluator eval;

		public EvalPlotter()
		{
			this.data = string.Empty;
			this.color = Color.Blue;

			this.eval = new Evaluator();
		}

		public void Init()
		{
			eval.Reset();
		}

		public float GetValue(float x)
		{
			eval.StoreVariable("x", x);
			
			return (float)eval.Evaluate(exp);
		}

		public Color PlotColor
		{
			get { return this.color; }
			set { this.color = value; }
			
		}

		/// <summary>
		/// sets expression data to plot
		/// might throw Parser or Tokenizer exception
		/// </summary>
		/// <param name="data"></param>
		public void SetData(string data)
		{
			this.data = data;
			Tokenizer tok = Tokenizer.FromString(data);
			AParser parser = new AParser(tok);

			this.exp = parser.Parse();
		}

		public string GetData() { return this.data; }

		public override string ToString()
		{
			return this.data; 
		}

	}

}
